from docopt import docopt
from usefulpy import logic

def handle():
  command_router = logic.CommandRouter()
  docstring = command_router.build()

  arguments = docopt(docstring, version='useful.py 0.1.1')
  command_router.find(arguments)
  
if __name__ == "__main__":
  " Main application entry point. This is here mostly to make testing less painful "
  handle()